﻿using SkiaSharp;
using Syncfusion.Drawing;
using Syncfusion.Pdf;
using Syncfusion.Pdf.Graphics;
using Syncfusion.Pdf.Parsing;
using System;
using System.IO;

namespace ConsoleCore
{
    class Program
    {
        static void Main(string[] args)
        {

            ImageScale();
        }

        private static void ImageScale()
        {
            //Create a new PDF document   
            PdfDocument document = new PdfDocument();
            
            string convertedFormat = "jpeg";
            byte[] byteArray = File.ReadAllBytes("../../../Data/Autumn Leaves.jpg");
            byte[] _byteArray = ShrinkImage(byteArray, 1000, 950, out convertedFormat);

            MemoryStream image = new MemoryStream(_byteArray);

            PdfBitmap img = new PdfBitmap(image);
            PdfPage page = document.Pages.Add();
            //Draw image
            page.Graphics.DrawImage(img, 0, 0);
            
            MemoryStream stream = new MemoryStream();

            //Save and closes the documents 
            document.Save(stream);
            document.Close(true);

            File.WriteAllBytes("../../../Sample.pdf", stream.ToArray());
        }
        public static byte[] ShrinkImage(byte[] byteArray, int maxWidth, int maxHeight, out string resultFormat)

        {

            byte[] result = byteArray;

            resultFormat = ""; //Set it to default value.

            int Width = 0;

            int Height = 0;

            try

            {

                using (SKBitmap bitmap = SKBitmap.Decode(byteArray))

                {

                    double xRatio = (double)bitmap.Width / maxWidth;

                    double yRatio = (double)bitmap.Height / maxHeight;

                    double ratio = Math.Max(xRatio, yRatio);

                    int nnx = (int)Math.Floor(bitmap.Width / ratio);

                    int nny = (int)Math.Floor(bitmap.Height / ratio);

                    Width = bitmap.Width;

                    Height = bitmap.Height;

                    if (bitmap.Height > maxHeight && bitmap.Width > maxWidth)

                    {

                        using (SKBitmap resizedImage = new SKBitmap(nnx, nny, bitmap.ColorType, bitmap.AlphaType))

                        {

                            bool resized = bitmap.ScalePixels(resizedImage, SKFilterQuality.High);

                            if (resized && resizedImage != null)

                            {

                                string convertedFormat = "";

                                result = ConvertImageFormat(resizedImage, out convertedFormat, SKEncodedImageFormat.Jpeg);

                                resultFormat = convertedFormat;

                                Width = resizedImage.Width;

                                Height = resizedImage.Height;

                            }

                        }

                    }

                }

                return result;

            }

            catch (Exception ex)

            {



                return result;

            }

        }
        private static byte[] ConvertImageFormat(SKBitmap bitmap, out string resultFormat, SKEncodedImageFormat format, int Quality = 100)

        {

            byte[] result = null;

            resultFormat = format.ToString();

           
                using (MemoryStream memStream = new MemoryStream())

                {

                    using (SKManagedWStream wstream = new SKManagedWStream(memStream))

                    {

                        bitmap.Encode(wstream, format, Quality);

                        result = memStream.ToArray();

                        if (result == null)

                        {

                            resultFormat = "";

                        }

                    }

                    return result;

                }

            
        }



        
    }
}
